==> ejc-zdsmaterialb-api-3.0.0-20241114.025133-43-sources.jar: com/ejianc/business/zdsmaterial/material/vo/MaterialPropertyRelationVO.java <==
package com.ejianc.business.zdsmaterial.material.vo;

import com.ejianc.framework.skeleton.template.BaseVO;
import io.swagger.annotations.*;


/**
 * 材料属性关系
 * 
 * @author generator
 * 
 */
@ApiModel("材料属性关系")
public class MaterialPropertyRelationVO extends BaseVO {

    private static final long serialVersionUID = 4311026215085221691L;

    @ApiModelProperty("属性Id")
    private Long propertyId;
    @ApiModelProperty("物资Id")
    private Long materialId;
    @ApiModelProperty("分类属性值Id，可能为空，为空时说明此属性值在分类属性可选值列表中不存在")
    private Long propertyItemId;
    @ApiModelProperty("物资分类Id")
    private Long categoryId;
    @ApiModelProperty("属性")
    private String propertyValue;
    @ApiModelProperty("属性分类排序号")
    private Integer propertySequence;

    //标记属性值是否为新增属性值
    private Integer hasNewPropertyVal;

    @ApiModelProperty("产品代码停启用：0-停用，1-启用，默认停用")
    private Integer productCodeFlag;

    @ApiModelProperty("产品代码")
    private String productCode;

    public Integer getProductCodeFlag() {
        return productCodeFlag;
    }

    public void setProductCodeFlag(Integer productCodeFlag) {
        this.productCodeFlag = productCodeFlag;
    }

    public String getProductCode() {
        return productCode;
    }

    public void setProductCode(String productCode) {
        this.productCode = productCode;
    }

    private String propertyName;

    public String getPropertyName() {
        return propertyName;
    }

    public void setPropertyName(String propertyName) {
        this.propertyName = propertyName;
    }

    public Long getPropertyId() {
        return propertyId;
    }

    public void setPropertyId(Long propertyId) {
        this.propertyId = propertyId;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public Long getPropertyItemId() {
        return propertyItemId;
    }

    public void setPropertyItemId(Long propertyItemId) {
        this.propertyItemId = propertyItemId;
    }
    public Long getCategoryId() {
        return categoryId;
    }

    public void setCategoryId(Long categoryId) {
        this.categoryId = categoryId;
    }
    public String getPropertyValue() {
        return propertyValue;
    }

    public void setPropertyValue(String propertyValue) {
        this.propertyValue = propertyValue;
    }
    public Integer getPropertySequence() {
        return propertySequence;
    }

    public void setPropertySequence(Integer propertySequence) {
        this.propertySequence = propertySequence;
    }

    public Integer getHasNewPropertyVal() {
        return hasNewPropertyVal;
    }

    public void setHasNewPropertyVal(Integer hasNewPropertyVal) {
        this.hasNewPropertyVal = hasNewPropertyVal;
    }
}

==> ejc-zdsmaterialb-api-3.0.0-20251028.072614-68-sources.jar: com/ejianc/business/zdsmaterial/material/vo/MaterialPropertyRelationVO.java <==
package com.ejianc.business.zdsmaterial.material.vo;

import com.ejianc.framework.skeleton.template.BaseVO;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;


/**
 * 材料属性关系
 * 
 * @author generator
 * 
 */
@ApiModel("材料属性关系")
public class MaterialPropertyRelationVO extends BaseVO {

    private static final long serialVersionUID = 4311026215085221691L;

    @ApiModelProperty("属性Id")
    private Long propertyId;
    @ApiModelProperty("物资Id")
    private Long materialId;
    @ApiModelProperty("分类属性值Id，可能为空，为空时说明此属性值在分类属性可选值列表中不存在")
    private Long propertyItemId;
    @ApiModelProperty("物资分类Id")
    private Long categoryId;
    @ApiModelProperty("属性")
    private String propertyValue;
    @ApiModelProperty("属性分类排序号")
    private Integer propertySequence;

    //标记属性值是否为新增属性值
    private Integer hasNewPropertyVal;

    @ApiModelProperty("产品代码停启用：0-停用，1-启用，默认停用")
    private Integer productCodeFlag;

    @ApiModelProperty("产品代码")
    private String productCode;

    public Integer getProductCodeFlag() {
        return productCodeFlag;
    }

    public void setProductCodeFlag(Integer productCodeFlag) {
        this.productCodeFlag = productCodeFlag;
    }

    public String getProductCode() {
        return productCode;
    }

    public void setProductCode(String productCode) {
        this.productCode = productCode;
    }

    private String propertyName;

    public String getPropertyName() {
        return propertyName;
    }

    public void setPropertyName(String propertyName) {
        this.propertyName = propertyName;
    }

    public Long getPropertyId() {
        return propertyId;
    }

    public void setPropertyId(Long propertyId) {
        this.propertyId = propertyId;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public Long getPropertyItemId() {
        return propertyItemId;
    }

    public void setPropertyItemId(Long propertyItemId) {
        this.propertyItemId = propertyItemId;
    }
    public Long getCategoryId() {
        return categoryId;
    }

    public void setCategoryId(Long categoryId) {
        this.categoryId = categoryId;
    }
    public String getPropertyValue() {
        return propertyValue;
    }

    public void setPropertyValue(String propertyValue) {
        this.propertyValue = propertyValue;
    }
    public Integer getPropertySequence() {
        return propertySequence;
    }

    public void setPropertySequence(Integer propertySequence) {
        this.propertySequence = propertySequence;
    }

    public Integer getHasNewPropertyVal() {
        return hasNewPropertyVal;
    }

    public void setHasNewPropertyVal(Integer hasNewPropertyVal) {
        this.hasNewPropertyVal = hasNewPropertyVal;
    }
}
